@@ -2,9 +2,14 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-VERSION = (0,5,4)
+import django
+import sys
+
+VERSION = (0,5,5,0)
+RELEASE_DJANGO = ((1,2),(1,3))
+PYTHON_MIN = (2,4)
 APPLICATION_NAME = "Dynamic Link"
-VERSION_str = str(VERSION).strip('()').replace(',','.').replace(' ','')
+VERSION_str = str(VERSION[:3]).strip('()').replace(',','.').replace(' ','')
 VERSION_INFO = """
 Version: %s
 Modification date: 03.08.2011
@@ -12,6 +17,8 @@ Modification date: 03.08.2011
 Hints:
 
 
+- 0.5.4.1   Canges in setup.py - READM will now alsow be installed. Now if a package
+            is installed than help(dynamicLink) outputs the README.
 - 0.5.4     Bugfix: Installation failed on Windows in spite of "/" on the end
             of recursive-include in MANIFEST. 
             Now canged from "recursive-include folder/ *" to "recursive-include folder *"
@@ -48,4 +55,4 @@ Hints:
 
 TODO:
     - write more unittests
-""" % (VERSION_str,)
\ No newline at end of file
+""" % (VERSION_str,)
